@@ -53,14 +53,9 @@ var diskHfsCmd = &cobra.Command{
 	Use:           "hfs",
 	Short:         "🚧 List/Extract HFS+ files",
 	Args:          cobra.ExactArgs(1),
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) (err error) {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-
 		// flags
 		pattern := viper.GetString("disk.hfs.pattern")
 		flat := viper.GetBool("disk.hfs.flat")
