@@ -27,7 +27,6 @@ import (
 	"github.com/blacktop/ipsw/pkg/dyld"
 	"github.com/fatih/color"
 	"github.com/spf13/cobra"
-	"github.com/spf13/viper"
 )
 
 var symAddrColor = color.New(color.Faint).SprintfFunc()
@@ -75,12 +74,6 @@ var DyldCmd = &cobra.Command{
 	Aliases: []string{"dsc"},
 	Short:   "Parse dyld_shared_cache",
 	Args:    cobra.NoArgs,
-	PersistentPreRun: func(cmd *cobra.Command, args []string) {
-		viper.BindPFlag("color", cmd.Flags().Lookup("color"))
-		viper.BindPFlag("no-color", cmd.Flags().Lookup("no-color"))
-		viper.BindPFlag("verbose", cmd.Flags().Lookup("verbose"))
-		viper.BindPFlag("diff-tool", cmd.Flags().Lookup("diff-tool"))
-	},
 	Run: func(cmd *cobra.Command, args []string) {
 		cmd.Help()
 	},
