@@ -31,7 +31,6 @@ import (
 	"github.com/blacktop/go-macho"
 	"github.com/blacktop/go-macho/types/swift"
 	"github.com/blacktop/ipsw/pkg/dyld"
-	"github.com/fatih/color"
 	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
@@ -61,11 +60,6 @@ var dyldSearchSwiftCmd = &cobra.Command{
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) (err error) {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// flags
 		searchImages := viper.GetStringSlice("dyld.search.swift.image")
 		classReStr := viper.GetString("dyld.search.swift.class")
