@@ -30,7 +30,6 @@ import (
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/disass"
 	"github.com/blacktop/ipsw/pkg/dyld"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -65,11 +64,6 @@ var XrefCmd = &cobra.Command{
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		imageName := viper.GetString("dyld.xref.image")
 		// TODO: add slide support (add to output addrs)
 		slide := viper.GetUint64("dyld.xref.slide")
@@ -193,7 +187,7 @@ var XrefCmd = &cobra.Command{
 				engine := dyld.NewDyldDisass(f, &disass.Config{
 					Data:         data,
 					StartAddress: fn.StartAddr,
-					Quite:        true,
+					Quiet:        true,
 				})
 
 				if err := engine.Triage(); err != nil {
