@@ -142,7 +142,7 @@ var extractCmd = &cobra.Command{
 		}
 
 		// validate args
-		if !viper.GetBool("extract.kernel") && !viper.GetBool("extract.dyld") && !viper.IsSet("extract.dmg") &&
+		if !viper.GetBool("extract.kernel") && !viper.GetBool("extract.dyld") && viper.GetString("extract.dmg") == "" &&
 			!viper.GetBool("extract.dtree") && !viper.GetBool("extract.iboot") && !viper.GetBool("extract.sep") &&
 			!viper.GetBool("extract.sptm") && !viper.GetBool("extract.kbag") && !viper.GetBool("extract.sys-ver") &&
 			!viper.GetBool("extract.exclave") && len(viper.GetString("extract.pattern")) == 0 && !viper.GetBool("extract.fcs-key") {
@@ -243,24 +243,20 @@ var extractCmd = &cobra.Command{
 
 		if viper.GetString("extract.dmg") != "" {
 			config.DMGs = true
-			if viper.GetBool("extract.remote") {
-				log.Error("unable to extract File System DMG remotely (let the author know if this is something you want)")
-			} else {
-				log.Info("Extracting DMG")
-				out, err := extract.DMG(config)
+			log.Info("Extracting DMG")
+			out, err := extract.DMG(config)
+			if err != nil {
+				return err
+			}
+			if viper.GetBool("extract.json") {
+				dat, err := json.Marshal(out)
 				if err != nil {
-					return err
+					return fmt.Errorf("failed to marshal output paths as JSON: %s", err)
 				}
-				if viper.GetBool("extract.json") {
-					dat, err := json.Marshal(out)
-					if err != nil {
-						return fmt.Errorf("failed to marshal output paths as JSON: %s", err)
-					}
-					fmt.Println(string(dat))
-				} else {
-					for _, f := range out {
-						utils.Indent(log.Info, 2)("Created " + f)
-					}
+				fmt.Println(string(dat))
+			} else {
+				for _, f := range out {
+					utils.Indent(log.Info, 2)("Created " + f)
 				}
 			}
 		}
