@@ -22,7 +22,6 @@ THE SOFTWARE.
 package fw
 
 import (
-	"github.com/apex/log"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -46,10 +45,6 @@ var aneCmd = &cobra.Command{
 	Hidden: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-
 		// flags
 		// output := viper.GetString("fw.ane.output")
 
