@@ -23,7 +23,6 @@ package idev
 
 import (
 	"github.com/spf13/cobra"
-	"github.com/spf13/viper"
 )
 
 func init() {
@@ -36,12 +35,6 @@ var IDevCmd = &cobra.Command{
 	Aliases: []string{"usb"},
 	Short:   "USB connected device commands",
 	Args:    cobra.NoArgs,
-	PersistentPreRun: func(cmd *cobra.Command, args []string) {
-		viper.BindPFlag("color", cmd.Flags().Lookup("color"))
-		viper.BindPFlag("no-color", cmd.Flags().Lookup("no-color"))
-		viper.BindPFlag("verbose", cmd.Flags().Lookup("verbose"))
-		viper.BindPFlag("diff-tool", cmd.Flags().Lookup("diff-tool"))
-	},
 	Run: func(cmd *cobra.Command, args []string) {
 		cmd.Help()
 	},
