@@ -27,7 +27,6 @@ import (
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/usb/misagent"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -39,18 +38,12 @@ func init() {
 // provRmCmd represents the rm command
 var provRmCmd = &cobra.Command{
 	Use:           "rm <PROV>",
-	Short:         "Remove a provision profile",
-	SilenceUsage:  true,
+	Short:         "Remove a provisioning profile",
 	SilenceErrors: true,
 	Args:          cobra.ExactArgs(1),
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
-		udid, _ := cmd.Flags().GetString("udid")
+		udid := viper.GetString("idev.udid")
 
 		if len(udid) == 0 {
 			dev, err := utils.PickDevice()
