@@ -98,11 +98,6 @@ var machoSearchCmd = &cobra.Command{
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// flags
 		loadCmdReStr := viper.GetString("macho.search.load-command")
 		launchConstReStr := viper.GetString("macho.search.launch-const")
