@@ -58,7 +58,7 @@ var otaLsCmd = &cobra.Command{
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		ota, err := ota.Open(filepath.Clean(args[0]), viper.GetString("ota.key-val"))
+		ota, err := ota.Open(filepath.Clean(args[0]), ResolveAEAKeyFromFlags(args[0]))
 		if err != nil {
 			return fmt.Errorf("failed to open OTA file: %v", err)
 		}
@@ -89,7 +89,7 @@ var otaLsCmd = &cobra.Command{
 		fmt.Fprintf(w, "- [ OTA ASSETS FILES ] %s\n\n", strings.Repeat("-", 50))
 		for _, f := range ota.Files() {
 			if !f.IsDir() {
-				fmt.Fprintf(w, "%s\t%s\t%s\t%s\n", colorMode(f.Mode()), colorModTime(f.ModTime().Format(time.RFC3339)), colorSize(humanize.Bytes(uint64(f.Size()))), colorName(f.Path()))
+				fmt.Fprintf(w, "%s\t%s\t%s\t%s\n", colorMode(f.Mode()), colorModTime(f.ModTime().Format(time.RFC3339)), colorSize(humanize.Bytes(uint64(f.Size()))), colorName(f.Name()))
 			}
 		}
 		w.Flush()
