@@ -273,7 +273,7 @@ func getLocalOsfiles(q *ADBQuery) (OsFiles, error) {
 			return nil, fmt.Errorf("failed to create local copy of 'appledb' repo: %v", err)
 		}
 	} else {
-		utils.Indent(log.Info, 2)(fmt.Sprintf("Updating 'appledb' repo %s", filepath.Join(q.ConfigDir, "appledb")))
+		utils.Indent(log.Debug, 2)(fmt.Sprintf("Updating 'appledb' repo %s", filepath.Join(q.ConfigDir, "appledb")))
 		if _, err := utils.GitRefresh(filepath.Join(q.ConfigDir, "appledb")); err != nil {
 			return nil, fmt.Errorf("failed to update local copy of 'appledb' repo: %v", err)
 		}
