@@ -76,6 +76,11 @@ func scanDmg(ipswPath, dmgPath, dmgType, pemDB string, handler func(string, stri
 	visited := make(map[string]bool)
 	if err := filepath.Walk(mountPoint, func(path string, info os.FileInfo, err error) error {
 		if err != nil {
+			// Skip paths with permission errors gracefully
+			if os.IsPermission(err) {
+				log.Debugf("skipping path due to permission denied: %s", path)
+				return nil
+			}
 			log.Errorf("failed to walk mount %s: %v", path, err)
 			return nil
 		}
@@ -194,6 +199,11 @@ func ForEachMacho(folder string, handler func(string, *macho.File) error) error
 	visited := make(map[string]bool)
 	if err := filepath.Walk(folder, func(path string, info os.FileInfo, err error) error {
 		if err != nil {
+			// Skip paths with permission errors gracefully
+			if os.IsPermission(err) {
+				log.Debugf("skipping path due to permission denied: %s", path)
+				return nil
+			}
 			log.Errorf("failed to walk mount %s: %v", path, err)
 			return nil
 		}
