@@ -11,7 +11,7 @@ import (
 	"github.com/apex/log"
 	"github.com/blacktop/go-macho/pkg/trie"
 	"github.com/blacktop/go-macho/types"
-	"github.com/olekukonko/tablewriter"
+	"github.com/blacktop/ipsw/pkg/table"
 )
 
 //go:generate go tool stringer -type=closureType,linkKind -output closure_string.go
@@ -169,13 +169,13 @@ func (i CImage) String(d *File, verbose bool) string {
 			})
 			prevFOff += ds.FilePageCount() * i.PageSize()
 		}
-		table := tablewriter.NewWriter(tableString)
-		table.SetHeader([]string{"File Offset", "File Size", "VM Size", "Prot"})
-		table.SetBorders(tablewriter.Border{Left: true, Top: false, Right: true, Bottom: false})
-		table.SetCenterSeparator("|")
-		table.AppendBulk(mdata)
-		table.SetAlignment(tablewriter.ALIGN_LEFT)
-		table.Render()
+		tbl := table.NewStringBuilderTableWriter(tableString)
+		tbl.SetHeader([]string{"File Offset", "File Size", "VM Size", "Prot"})
+		tbl.SetBorders(nil)
+		tbl.SetCenterSeparator("|")
+		tbl.AppendBulk(mdata)
+		tbl.SetAlignment(1)
+		tbl.Render()
 
 		diskSegs += tableString.String()
 	}
