@@ -121,6 +121,7 @@ type astate struct {
 	Starts   bool
 	ObjC     bool
 	Slide    bool
+	Swift    bool
 }
 
 func (a *astate) SetDeps(done bool) {
@@ -225,6 +226,18 @@ func (a *astate) IsSlideInfoDone() bool {
 	return a.Slide
 }
 
+func (a *astate) SetSwift(done bool) {
+	a.mu.Lock()
+	a.Swift = done
+	a.mu.Unlock()
+}
+
+func (a *astate) IsSwiftDone() bool {
+	a.mu.Lock()
+	defer a.mu.Unlock()
+	return a.Swift
+}
+
 type analysis struct {
 	State        astate
 	Dependencies []string
@@ -519,6 +532,11 @@ func (i *CacheImage) GetPartialMacho() (*macho.File, error) {
 // Analyze analyzes an image by parsing it's symbols, stubs and GOT
 func (i *CacheImage) Analyze() error {
 
+	if err := i.ParseObjC(); err != nil {
+		log.Errorf("failed to parse objc data for image %s: %v", filepath.Base(i.Name), err)
+		// return fmt.Errorf("failed to parse objc data for image %s: %v", filepath.Base(i.Name), err) FIXME: should this error out?
+	}
+
 	if err := i.ParsePublicSymbols(false); err != nil {
 		log.Errorf("failed to parse exported symbols for %s: %w", i.Name, err)
 	}
@@ -529,15 +547,20 @@ func (i *CacheImage) Analyze() error {
 		}
 	}
 
-	if err := i.ParseObjC(); err != nil {
-		log.Errorf("failed to parse objc data for image %s: %v", filepath.Base(i.Name), err)
-		// return fmt.Errorf("failed to parse objc data for image %s: %v", filepath.Base(i.Name), err) FIXME: should this error out?
-	}
-
 	if !i.cache.IsArm64() {
 		utils.Indent(log.Warn, 2)("image analysis of stubs and GOT only works on arm64 architectures")
 	}
 
+	if !i.Analysis.State.IsSwiftDone() {
+		// TODO: add more swift runtime metadata
+		if i.cache.IsArm64() {
+			if err := i.ParseSwiftStrings(); err != nil {
+				return fmt.Errorf("failed to parse swift strings for %s: %w", i.Name, err)
+			}
+		}
+		i.Analysis.State.SetSwift(true)
+	}
+
 	if !i.Analysis.State.IsSlideInfoDone() {
 		if err := i.ParseSlideInfo(); err != nil {
 			return fmt.Errorf("failed to parse slide info for %s: %w", i.Name, err)
@@ -742,15 +765,32 @@ func (i *CacheImage) ParseObjC() error {
 // ParseGOT parse global offset table in MachO
 func (i *CacheImage) ParseGOT() error {
 
+	i.Analysis.GotPointers = make(map[uint64]uint64)
+
 	m, err := i.GetPartialMacho()
 	if err != nil {
 		return fmt.Errorf("failed to get MachO for image %s; %v", i.Name, err)
 	}
 	defer m.Close()
 
-	i.Analysis.GotPointers, err = disass.ParseGotPtrs(m)
-	if err != nil {
-		return err
+	for _, secName := range []string{"__got", "__auth_got", "__auth_ptr"} {
+		for _, sec := range m.Sections {
+			if (sec.Seg == "__AUTH_CONST" || sec.Seg == "__DATA_CONST") && sec.Name == secName {
+				dat := make([]byte, sec.Size)
+				if _, err := i.ReadAtAddr(dat, sec.Addr); err != nil {
+					return fmt.Errorf("failed to read GOT section %s: %v", secName, err)
+				}
+				ptrs := make([]uint64, sec.Size/8)
+				if err := binary.Read(bytes.NewReader(dat), binary.LittleEndian, &ptrs); err != nil {
+					return fmt.Errorf("failed to read %s.%s got pointers; %v", sec.Seg, sec.Name, err)
+				}
+				for idx, ptr := range ptrs {
+					if ptr != 0 {
+						i.Analysis.GotPointers[sec.Addr+uint64(idx*8)] = i.cache.SlideInfo.SlidePointer(ptr)
+					}
+				}
+			}
+		}
 	}
 
 	i.Analysis.State.SetGot(true)
@@ -808,6 +848,42 @@ func (i *CacheImage) ParseHelpers() error {
 	return nil
 }
 
+func (i *CacheImage) ParseSwiftStrings() error {
+
+	m, err := i.GetPartialMacho()
+	if err != nil {
+		return fmt.Errorf("failed to get MachO for image %s; %v", i.Name, err)
+	}
+
+	text := m.Section("__TEXT", "__text")
+	if text == nil {
+		return fmt.Errorf("no __TEXT.__text section found")
+	}
+
+	data, err := text.Data()
+	if err != nil {
+		return fmt.Errorf("failed to get __TEXT.__text data: %v", err)
+	}
+
+	engine := disass.NewMachoDisass(m, &disass.Config{
+		Data:         data,
+		StartAddress: text.Addr,
+		Middle:       text.Addr + text.Size,
+	})
+
+	strs, err := engine.FindSwiftStrings()
+	if err != nil {
+		return fmt.Errorf("failed to find swift strings: %v", err)
+	}
+	for addr, str := range strs {
+		if len(str) > 0 {
+			i.cache.AddressToSymbol[addr] = fmt.Sprintf("%v", str)
+		}
+	}
+
+	return nil
+}
+
 // ParseLocalSymbols parses and caches, with the option to dump, all the local/private symbols for an image
 func (i *CacheImage) ParseLocalSymbols(dump bool) error {
 
